@@ -2,16 +2,16 @@ package Import::Export;
 
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our %EX;
 
 our %EXTYPE = (
-    	 '&' => \&_export_code,
-	 '$' => \&_export_scalar,
-	 '@' => \&_export_array,
-	 '%' => \&_export_hash,
-	 '*' => \&_export_glob,
+	'&' => \&_export_code,
+	'$' => \&_export_scalar,
+	'@' => \&_export_array,
+	'%' => \&_export_hash,
+	'*' => \&_export_glob,
 );
 
 sub import {
@@ -28,7 +28,7 @@ sub export {
 	my ($pkg, $caller) = (shift, shift);
 	while (my $ex = shift) {
 		my $type;
-		if (! $EX{$ex} ) {
+		if ( ! $EX{$ex} ) {
 		 	my @export = grep { 
 				grep { $_ =~ m{\Q$ex\E} } @{ $EX{$_} }
 			} keys %EX;
@@ -41,7 +41,7 @@ sub export {
 		$pkg->can($type) and next;
 
 		my $exporting = $EXTYPE{$type} or Carp::croak("Cant export symbol $ex");		
-        	*{"${caller}::${ex}"} = $exporting->($pkg, $ex);
+		*{"${caller}::${ex}"} = $exporting->($pkg, $ex);
 	}
 }
 
@@ -57,7 +57,7 @@ Import::Export - Exporting
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -70,8 +70,9 @@ Quick summary of what the module does.
     use base 'Import::Export';
 
     our %EX = (
-	one => [all],
-    );
+		one => [qw/all/],
+    	two => [qw/all another/]
+	);
     
     sub one { 'Echo' }
 
@@ -79,6 +80,10 @@ Quick summary of what the module does.
 
     use One qw/all/;
 
+	.....
+
+	use One qw/one/;
+
 =head1 AUTHOR
 
 Robert Acock, C<< <thisusedtobeanemail at gmail.com> >>
